@@ -25,10 +25,10 @@
   new_key <- cn[cn %in% key_vars(x)]
 
   if (!missing(i)) {
-    if (anyDuplicated.default(i) > 0) return(as_tibble(res))
+    if (vec_duplicate_any(i) > 0) return(as_tibble(res))
   }
 
-  not_tsibble <- !(index_var(x) %in% cn) || NROW(res) > NROW(x)
+  not_tsibble <- !(index_var(x) %in% cn) || vec_size(res) > vec_size(x)
   maybe_tsibble <- n_keys(x) > 1 && !all(is.element(key(x), new_key))
   if (not_tsibble || maybe_tsibble) {
     as_tibble(res)
@@ -36,12 +36,12 @@
     build_tsibble(
       res,
       key = !!new_key, index = !!index(x), index2 = !!index2(x),
-      interval = is_regular(x), ordered = is_ordered(x), validate = FALSE
+      interval = interval(x), ordered = is_ordered(x), validate = FALSE
     )
   } else { # index2 not there
     build_tsibble(
       res,
-      key = !!new_key, index = !!index(x), interval = is_regular(x),
+      key = !!new_key, index = !!index(x), interval = interval(x),
       ordered = is_ordered(x), validate = FALSE
     )
   }
