@@ -13,4 +13,8 @@ test_that("interval class", {
   int <- new_interval(hour = 1, minute = 30)
   expect_is(int, "interval")
   expect_equal(format(int), "1h 30m")
+  expect_is(new_interval(), "interval")
+  expect_equal(format(new_interval()), "?")
+  expect_is(new_interval(NULL), "interval")
+  expect_equal(format(new_interval(NULL)), "!")
 })
